=======
Contact
=======

Executive summary
=================

Reach out through GitHub issues or email caldav@plann.no.  If you feel ignored, be aware that messages sometimes are drowned in spam or forgotten about because I had more urgent issues to handle.  Urgent issues may be escalated by reaching out through +47-91700050 or @tobixen on different alternative communication services.  Please keep in mind that things lie providing food to the table for himself and the family typially will have a higher priority than fiddling with the calendaring projects for free on a hobby basis.

The maintainer
==============

As of 2025-11, the CalDAV project is (and has been for many year) maintained by Tobias Brox.  While the project has many contributors, all changesets are currently approved by him, and he is also the major contributor code and time to the project.  Contact may be done privately towards him or in group channels - currently the only thing resembling a "group channel" is the GitHub issues and GitHub discussions.  For the rest of the document, "I", "me" and "my", etc will refer to Tobias.

Priorities
==========

I'm constantly busy.  Sometimes it takes months between each time I have capacity to look into the CalDAV project.  Other times I may be able to work almost full-time on the project for a period.  In any case the number of "issues" tend to grow faster than what I can handle them.  "CalDAV support" may sound like a simple thing that could be carved out in the rocks once and forgot about, but the reality is a bit different, particularly because:

* There is a jungle of servers and cloud services out there, and all of the developers have read the RFC a bit differently - so what works on one server does not always work on another server.  Quite much of my time is devoted to investigating server behaviour, creating workarounds and making a predictable API that works on as many servers as possible.
* There are many RFC documents to read, and there keep getting more of them.  Creating the best possible support for all relevant standards is a never-ending project.

Perhaps you find a show-stopper for the project - be it performance issues, compatibiliity issues with the calendar server you're using, some missing feature or a bug.  Perhaps your business plan depends on it.  The nice thing with open source projects is that you theoretically have both the possibility and the right to fix things on your own, or hire someone to fix it.  Or you can toss out an issue on the issue tracker and hope that I will find the time and inspiration to fix the issue - for free, no a hobby basis.  Please consider that I do need to find a way to bring food to the table for me and my family.

GitHub
======

I am a bit wary of depending too much on GitHub - but the project currently lives on GitHub, the best practice for reporting issues is to raise it at https://github.com/python-caldav/caldav/issues/

Sometimes the issues section in GitHub is also used for questions.  Some purists may cringe at such an abuse of the issues tracker, but generally I try to be helpful and answer questions there.

GitHub also has a discussions section at https://github.com/python-caldav/caldav/discussions - I haven't tested it out yet, but it may possibly be a good place for raising questions and suggestions if they don't fit neatly in as an issue.

Email
=====

The official email address for the project is caldav@plann.no.  Disclaimer: as of november 2025-11 I don't have a good system for handling spam, if your email was ignored it may be unintentionally.  Try sending again, include "CalDAV" and "Python" in the subject maybe, or try other channels.

IRC
===

The project has an official IRC channel #caldav at OFTC ... but the IRC protocol has some serious short-comings, this should have been understood already in august 1990 when the Eris server had to be disconnected, it got worse summer 1996 when IRCNet and EFNet was split.  While IRC had it's peak in the number of users worldwide sometime in the 2000s, the growth stagnated compared to the growth in Internet users worldwide during the late 90s - inferior services based on closed protocols and binary software distributions like ICQ was growing much faster.  During the 2000s FreeNode became the leading network for open source support, but then there was the Andrew Lee crises in 2021.

Digression.  To make a long history short: I'm not a big user of IRC anymore, my IRC client may be rather dormant and it may take months before I notice any legitimate activity on the channel.

Signal, Telegram, WhatsApp
==========================

Feel free to try to reach out to the maintainer at +47-91700050 or handle @tobixen if you prefer using any of those services.  Particularly for Telegram I have big problems with spam now, so notifications may be turned off, and any messages like "Hi!" or "Can I ask you a question?" may cause ignoring, blocking or reporting.  Please state why you are contacting me as well as an indication of what hat I shall wear.  Voice messages, voice calls and videos may be fine if I happen to be alone, in a quiet environment and/or with my headset over my ears - sometimes it may take me a month or two before I have favorable conditions for listening to a voice message.

Deltachat
=========

I've tried Delta Chat and I like it.  If anyone else uses it, then I will consider making a CalDAV channel there.

Matrix
======

Matrix is the future?  If you agree, notify me and I will create a matrix server on plann.no as well as an official matrix channel.
